Crate delta

Crate delta 

Structs

Change
Represents a change in the database.
Delta
Delta is the main struct representing a node in the Delta network. It can function as either a Master or Auxiliary node. The struct contains various attributes and methods to manage and interact with the node.

Enums

ConnectionParams
Represents the connection parameters for a Delta node.
DeltaConfig
Configuration options for initializing a Delta node.
NodeType
The type of node in the Delta network.
TransactionType
Represents the type of a database transaction.
Value
Represents the value stored in a database cell.