pub enum NodeType {
Master,
Auxiliary,
}Expand description
The type of node in the Delta network.
A NodeType can be:
Master: Represents the primary node that can manage and coordinate with auxiliary nodes.Auxiliary: Represents a secondary node that connects to and syncs with the master node.
Variants