pub struct Change {
pub id: String,
pub table_name: String,
pub row_id: String,
pub column_name: String,
pub value: Value,
pub cell_version: u64,
pub table_version: u64,
pub db_version: u64,
pub node_id: String,
pub transaction_type: TransactionType,
}Expand description
Represents a change in the database.
Change contains detailed information about a specific change in the database,
including the affected table, row, column, and the new value.
Fields
id: Stringtable_name: Stringrow_id: Stringcolumn_name: Stringvalue: Valuecell_version: u64table_version: u64db_version: u64node_id: Stringtransaction_type: TransactionTypeTrait Implementations