Structs
- Change
- Represents a change in the database.
- Delta
Deltais the main struct representing a node in the Delta network. It can function as either a Master or Auxiliary node. The struct contains various attributes and methods to manage and interact with the node.
Enums
- Connection
Params - Represents the connection parameters for a Delta node.
- Delta
Config - Configuration options for initializing a Delta node.
- Node
Type - The type of node in the Delta network.
- Transaction
Type - Represents the type of a database transaction.
- Value
- Represents the value stored in a database cell.