ConnectionParams

Enum ConnectionParams 

pub enum ConnectionParams {
    Url(String),
    IpPort(String, u16),
}
Represents the connection parameters for a Delta node.

ConnectionParams can be:

  • Url: A URL string to connect to a node.
  • IpPort: An IP address and port combination to connect to a node.

Variants



Url(String)

Connection parameter representing a URL.

Fields

  • 0 - A string containing the URL.


IpPort(String, u16)

Connection parameter representing an IP address and port.

Fields

  • 0 - A string containing the IP address.
  • 1 - A u16 containing the port number.

Implementations

Source

impl ConnectionParams

pub fn is_url(&self) -> bool

Checks if the connection parameters are a URL.

Returns

A boolean indicating whether the connection parameters are a URL.

Examples
let params = ConnectionParams::Url("http://example.com".to_string());
assert!(params.is_url());
assert!(!params.is_ip_port());
pub fn is_ip_port(&self) -> bool

Checks if the connection parameters are an IP address and port combination.

Returns

A boolean indicating whether the connection parameters are an IP address and port combination.

Examples
let params = ConnectionParams::IpPort("192.168.1.1".to_string(), 8080);
assert!(params.is_ip_port());
assert!(!params.is_url());